diff --git a/lib/private/files/objectstore/noopscanner.php b/lib/private/files/objectstore/noopscanner.php
index 59ca17719713edc3795b3dee43f9fc4860d07546..7750a8d5529696370796d611baa67654bea119c1 100644
--- a/lib/private/files/objectstore/noopscanner.php
+++ b/lib/private/files/objectstore/noopscanner.php
@@ -33,10 +33,11 @@ class NoopScanner extends Scanner {
 	 *
 	 * @param string $file
 	 * @param int $reuseExisting
 	 * @param bool $parentExistsInCache
 	 * @return array with metadata of the scanned file
 	 */
-	public function scanFile($file, $reuseExisting = 0, $parentExistsInCache = false) {
+	public function scanFile($file, $reuseExisting = 0, $parentId = -1, $cacheData = null) {
 		return array();
 	}
 
@@ -58,11 +59,11 @@ class NoopScanner extends Scanner {
 	 * @param string $path
 	 * @param bool $recursive
 	 * @param int $reuse
+	 * @param array $folderData existing cache data for the folder to be scanned
 	 * @return int the size of the scanned folder or -1 if the size is unknown at this stage
 	 */
-	public function scanChildren($path, $recursive = Storage::SCAN_RECURSIVE, $reuse = -1) {
-		$size = 0;
-		return $size;
+	protected function scanChildren($path, $recursive = self::SCAN_RECURSIVE, $reuse = -1, $folderData = null) {
+		return 0;
 	}
 
 	/**
@@ -33,10 +33,11 @@ class NoopScanner extends Scanner {
 	 * @param string $file
 	 * @param int $reuseExisting
-	 * @param bool $parentExistsInCache
-	 * @return array with metadata of the scanned file
+	 * @param int $parentId
+	 * @param array|null $cacheData existing data in the cache for the file to be scanned
+	 * @return array an array of metadata of the scanned file
 	 */